#Lophiiform feeding morphologies (Using Hart Phylogeny)

setwd("C:/Users/zachh/Dropbox/ceratioid_morphology/Post Review1/R scripts")
getwd()
new.data=read.csv("transformed_all_species.csv")

#Coloring schemes: 
group= new.data$group
families=new.data$families

# make species names the row names, not a separate column
rownames(new.data) = new.data$`data$Species`
rownames(new.data)
new.data <- new.data[,-1]
head(new.data)


# confirm that the number of rows (species) and number of columns (variables) is what you want
dim(new.data)
### PCA time
library(tidyverse)
library(ggfortify)
library(RColorBrewer)
library(ape)

#Now take the master data set and make it match with only the species in the trees
#species not in the tree coded as 0. Column 'uce' refers to the names in the 
#Hart et al 2022 phylogeny.
data.u1=subset(new.data, uce !="0")
#confirm that the transformation worked and that all '0's are gone
data.u1$uce
head(data.u1)

#now read in the tree
#ensure that the names in the tips of your trees match the names in your df

tree.u = read.tree("hart_ultrametric.tree")
plot(tree.u)
#now lets drop the two outgroups 
tree.u=drop.tip(tree.u, tip="Antigonia_capros_07_Anca_078")
tree.u=drop.tip(tree.u, tip="Sphoeroides_dorsalis_T3970")
tree.u=drop.tip(tree.u, tip="Rhynchactis_macrothrix_04_016") #(spp does not have teeth)
#check
plot(tree.u)

#match the order of the data to the order of the tips in our tree
data.u=data.u1[match(tree.u$tip.label, data.u1$uce),]
rownames(data.u)=data.u$uce



#install phytools and get ready for phylo pca
library(phytools)

#lets see how this goes
pca.u=phyl.pca(tree.u, data.u[,1:19], method='BM', mode='corr')
biplot(pca.u)

#Now we need to make a tibble so that we can edit our figures in ggplot2
#lets name it pca.tib
pca.tib=
  # first convert the pca results to a tibble
  as_tibble(pca.u$S) %>%
  # now we'll add the ceratioid data
  bind_cols(data.u)


fig1= ggplot(pca.tib, aes(x=PC1, y= PC2)) +
  geom_point(aes(colour=group), size= 2)+
  ggtitle('Hart et al. 2022s', 
          subtitle= 'Total Variation Explained (80.7%)') +
  xlab('PC1 (35.8%)') +
  ylab('PC2 (22.4%)') +
  scale_colour_discrete(name="Groups") +
scale_color_manual(values = c( "#2E2F97" , "#1CBDC2", "#F3766E"))
fig1= fig1 + theme_classic()

fig1

#now lets create aesethic clusters
pca_hull = 
  pca.tib %>% 
  group_by(group) %>% 
  slice(chull(PC1, PC2))

#calculate surface area of convex hulls


#add polygons
fig1 <- 
  fig1 +
  geom_polygon(data = pca_hull, 
               aes(fill = group,
                   colour = group),
               alpha = .09,
               show.legend = FALSE) +
  scale_fill_manual(values = c( "#2E2F97" , "#1CBDC2", "#F3766E"))
fig1


#Now we want to add our eigenvectors/loadings back to the plot.
#We need to createa new dataframe for the eigenvectors

pca_load = as_tibble(pca.u$L, rownames = 'variables')
#Now lets add this information to fig1


fig1= 
  fig1+
  geom_segment(data = pca_load, 
               aes(x = 0, y = 0, 
                   xend = PC1*3,
                   yend = PC2*3),
               arrow = arrow(length = unit(0.5, 'picas'))) 

pca.scr=pca.u$L
fig1=
  fig1 +
  annotate('text', x = (pca_load$PC1*5), y = (pca_load$PC2*5),
           label = pca_load$variables,
           size = 5.0)


fig1

fig1.id=
  fig1+
  geom_text(label=data.u$spp)
fig1.id


#apply broken stick method to identify important axes
library(PCDimension)
pov <- (pca.u$Eval^2)/sum(pca.u$Eval^2)
brokenStick(1:19, 19)
test1=bsDimension(pov)
test1

##Regressions and model fitting####
library(phylolm)
library(nlme)
library(geiger)
#44 = number of tips + 1 (aka root node)
#collapse tree to star tree for OLS model
tree_ols = collapse.to.star(tree.u, 44)
plot(tree_ols)

#make objects out of variables to make coding easier
ap.p=data.u$ap
li.lo.p=data.u$li.lo.reg
meantooth=data.u$meantooth #(upper and lower jaw teeth, 10 total)
meandist=data.u$meanspace
#####fitting meantooth~li.lo scores
fit_ols<-phylolm(meantooth~li.lo.p, data=data.u,phy=tree_ols,model=c("BM"))
summary(fit_ols)


fit_bm<-phylolm(meantooth~li.lo.p,data=data.u,phy=tree.u,model=c("BM"))
summary(fit_bm)


fit_ou<-phylolm(meantooth~li.lo.p,data=data.u,phy=tree.u,model=c("OUrandomRoot"))
summary(fit_ou)


#"Lambda" corresponds to a mixed model; we ended up not using this model (but I did it anyway)
fit_lambda<-phylolm(meantooth~li.lo.p ,data=data.u,phy=tree.u ,model=c("lambda"))
summary(fit_lambda)


#now master plot of tooth lengh and bite strategy
plot(x = li.lo.p,
     y = meantooth,
     xlab = "Jaw closing mechanical advantage (MA)",
     ylab = "Average tooth length", cex.lab=1, cex.axis = .75, 
     col=as.factor(data.u$group), pch=16, cex = 2)
abline(fit_ols,col="black", lwd = 3)
abline(fit_bm, col = "grey 50", lwd = 3)
abline(fit_ou, col = "grey", lwd = 3)

#-- AICS(OLS, BM, OU): 39.78, 198.85, 111.88 

#########fitting ap.p~li.lo scores
fit_ols1<-phylolm(ap.p~li.lo.p, data=data.u,phy=tree_ols,model=c("BM"))
summary(fit_ols1)

fit_bm1<-phylolm(ap.p~li.lo.p,data=data.u,phy=tree.u,model=c("BM"))
summary(fit_bm1)


fit_ou1<-phylolm(ap.p~li.lo.p,data=data.u,phy=tree.u,model=c("OUrandomRoot"))
summary(fit_ou1)

#"Lambda" corresponds to a mixed model; we ended up not using this model (but I did it anyway)
fit_lambda1<-phylolm(ap.p~li.lo.p ,data=data.u,phy=tree.u ,model=c("lambda"))
summary(fit_lambda1)

#now master plot of ascending process and biting strategy
plot(x = li.lo.p,
     y = ap.p,
     xlab = "Jaw closing mechanical advantage (MA)",
     ylab = "Height of the ascending process", cex.lab=1, cex.axis = .75, 
     col=as.factor(data.u$group), pch=16, cex =2)
abline(fit_ols1,col="black", lwd = 3)
abline(fit_bm1, col = "grey 50", lwd = 3)
abline(fit_ou1, col = "grey", lwd = 3)

#####Now model fitting for meantooth~meandist
fit_ols2<-phylolm(meantooth~meandist, data=data.u,phy=tree_ols,model=c("BM"))
summary(fit_ols2)

fit_bm2<-phylolm(meantooth~meandist,data=data.u,phy=tree.u,model=c("BM"))
summary(fit_bm2)


fit_ou2<-phylolm(meantooth~meandist,data=data.u,phy=tree.u,model=c("OUrandomRoot"))
summary(fit_ou2)


#lets test phylogenetic signal
#"Lambda" corresponds to a mixed model; we ended up not using this model (but I did it anyway)
fit_lambda2<-phylolm(meantooth~meandist ,data=data.u,phy=tree.u ,model=c("lambda"))
summary(fit_lambda2)

#now master plot of tooth length and spacing
plot(x = meandist,
     y = meantooth,
     xlab = "Average tooth spacing",
     ylab = "Average tooth length", cex.lab=1, cex.axis = .75,
     col=as.factor(data.u$group), pch=16, cex =2)
abline(fit_ols2,col="black", lwd = 3)
abline(fit_bm2, col = "grey 50", lwd = 3)
abline(fit_ou2, col = "grey", lwd = 3)


##akaike weights!!!
library(qpcR)
#length lever
x = c(42.08, 64.53, 43.82)
akaike.weights(x)

#ap lever
x1 = c(127.52, 83.07, 88.09)
akaike.weights(x1)

#length and dist
x2 = c(36.78, 68.02, 39.30)
akaike.weights(x2)

#


###ancestral state reconstructions

#library(phylogram)
#tree.clade=as.dendrogram.phylo(tree.u)
tree.clade=tree.u
library(maps)

#lets make the tree now match the names of the CT scans
tree.clade$tip.label=data.u$spp
###First reconstruct for tooth length
svl<-setNames(meantooth,data.u$spp)
svl

fit = fastAnc(tree.clade, svl, vars=T, CI= T)

obj<-contMap(tree.clade,svl,plot=FALSE)
obj<- setMap(obj, invert=T)
obj

#note for extracting these plots: if you squish it too much in the viewer
#the branches will blend together
plot(obj,legend=0.7*max(nodeHeights(tree.clade)),
     sig=2,fsize=c(0.7,0.9), tiplabels = group)
title('Average tooth length')




####li lo reconstruction
#Multiply by -1 and invert colors so that plot color scheme
#matches that of tooth length
svl1<-setNames(li.lo.p*-1,data.u$spp)
svl1

fit1 = fastAnc(tree.clade, svl1, vars=T, CI= T)

obj1<-contMap(tree.clade,svl1,plot=FALSE)
obj1<-setMap(obj1, invert=T)
obj1

plot(obj1,legend=0.7*max(nodeHeights(tree.clade)),
     sig=2,fsize=c(0.7,0.9)) + 
  title("Jaw closing mechanichal advantage (MA)")
######ascending process ancestral state
svl2<-setNames(ap.p,data.u$spp)
svl2

fit2 = fastAnc(tree.clade, svl2, vars=T, CI= T)

obj2<-contMap(tree.clade,svl2,plot=FALSE)
obj2

plot(obj2,legend=0.7*max(nodeHeights(tree.clade)),
     sig=2,fsize=c(0.7,0.9))
title("Height of the ascending process")

###Tooth spacing reconstruction
svl3<-setNames(meandist,data.u$spp)
svl3

fit3 = fastAnc(tree.clade, svl3, vars=T, CI= T)

obj3<-contMap(tree.clade,svl3,plot=FALSE)
obj3<- setMap(obj3, invert=T)
obj3

plot(obj3,legend=0.7*max(nodeHeights(tree.clade)),
     sig=2,fsize=c(0.7,0.9))

title("Average tooth spacing")


