#Lophiiform feeding morphologies(non phylogenetic analyses)

setwd("C:/Users/zachh/Dropbox/ceratioid_morphology/Post Review1/R scripts")
getwd()
new.data=read.csv("transformed_all_species.csv")

### 
library(tidyverse)
library(ggfortify)
library(RColorBrewer)

#Coloring schemes: 
group= new.data$group
families=new.data$families

# make species names the row names, not a separate column
rownames(new.data) = new.data$`data$Species`
rownames(new.data)
new.data <- new.data[,-1]
head(new.data)

#make pca with correlation matrix and color by group
pca_values = prcomp(new.data[,c(1:19)], scale= T)
autoplot(pca_values, data=new.data,
         labels=T, loadings.label=T,
         colour='group') +
  scale_color_manual(values = c( "#2E2F97" , "#1CBDC2", "#F3766E"))

#calculate the number of statistically important axes
library(PCDimension)
pov <- (pca_values$sdev^2)/sum(pca_values$sdev^2)
brokenStick(1:19, 19)
test1=bsDimension(pov)
test1

# names(cols)<-c("\"Wolftrap angler\"" , "Benthic lophiiforms", "Ceratioids")

#Now we need to make a tibble so that we can edit our figures in ggplot2
#lets name it pca.tib
pca.tib=
  # first convert the pca results to a tibble
  as_tibble(pca_values$x) %>%
  # now we'll add the ceratioid data
  bind_cols(new.data)

#make better figures.
#Making fig1

fig1= ggplot(pca.tib, aes(x=PC1, y= PC2), cex.axis = 2) +
  geom_point(size = 3.5, aes(colour=group))+
  xlab('PC1 (41.12%)') +
  ylab('PC2 (19.2%)') +
  scale_colour_discrete(name="Groups")
fig1 = fig1 + theme_classic()


fig1 = fig1 +  
  scale_color_manual(values = c( "#2E2F97" , "#1CBDC2", "#F3766E"))  

#Create aesthetic clusters 
#extract all of the data points that do not need to be included in 
#polygons
#
pca_hull = 
  pca.tib %>% 
  group_by(group) %>% 
  slice(chull(PC1, PC2)) 


#add polygons
fig1 <- 
  fig1 +
  geom_polygon(data = pca_hull, 
               aes(fill = group,
                   colour = group) ,
               alpha = .1,
               show.legend = FALSE) +
  scale_fill_manual(values = c( "#2E2F97" , "#1CBDC2", "#F3766E"))  
  
fig1
#Now we want to add our eigenvectors/loadings back to the plot.
#We need to createa new dataframe for the eigenvectors

pca_load = as_tibble(pca_values$rotation, rownames = 'variables')
#Now lets add this information to fig1


fig1= 
  fig1+
  geom_segment(data = pca_load, 
               aes(x = 0, y = 0, 
                   xend = PC1*5,
                   yend = PC2*5),
               arrow = arrow(length = unit(0.5, 'picas'))) 

pca.scr=pca_values$x
fig1=
  fig1 +
  annotate('text', x = (pca_load$PC1*5), y = (pca_load$PC2*5),
           label = pca_load$variables,
           size = 5.0)
fig1


#w/ species names
fig1.id=
  fig1+
  geom_text(label=new.data$spp)
fig1.id


#


# now make the same thing for the families

#make better figures.
#Making fig1
fig2= ggplot(pca.tib, aes(x=PC1, y= PC2)) +
  geom_point(size = 3.5, aes(colour=families))
fig2= fig2 +  theme_bw()


fig2

#Create aesthetic clusters
#extract all of the data points that do not need to be included in 
#polygons
#
pca_hull2 = 
  pca.tib %>% 
  group_by(families) %>% 
  slice(chull(PC1, PC2))

#add polygons
fig2.final <- 
  fig2 +
  geom_polygon(data = pca_hull2,
               aes(fill = families,
                   colour = families),
               alpha = .3,
               show.legend = TRUE)
fig2.final = fig2.final + theme_classic()
fig2.final




#now lets combine these figs for the figure
library(gridExtra)
grid.arrange(fig1, fig2.final, ncol = 2)

#op <- par(mfrow = c(1, 2), # 2 x 2 pictures on one plot
#pty = "s")       # square plotting region,
# independent of device size

par(mfrow=c(1,2),
    pty ="s") 
plot(fig1)
plot(fig2.final)


###Clustering analysis
library(phytools)
# clustering analsysis
rownames(new.data)=new.data$spp
clust1 <- hclust(dist(new.data[,c(1:19)]), method = "ward.D2")
clust1 <- as.phylo(clust1)
#clust1= rect.hclust(clust1, borders = as.factor(group))
plot(clust1)

